========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/murano.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

Murano
======

Murano Project introduces an application catalog, which allows application
developers and cloud administrators to publish various cloud-ready
applications in a browsable categorised catalog. Cloud users
-- including inexperienced ones -- can then use the catalog to
compose reliable application environments with the push of a button.


Project Resources
-----------------

* `Murano Official Documentation <https://docs.openstack.org/murano/latest/>`_

* Project status, bugs, and blueprints are tracked on
  `Launchpad <https://launchpad.net/murano>`_

* Additional resources are linked from the project
  `Wiki <https://wiki.openstack.org/wiki/Murano>`_ page

* `Python client <https://opendev.org/openstack/python-muranoclient>`_

License
-------

Apache License Version 2.0 http://www.apache.org/licenses/LICENSE-2.0


Release Notes
-------------

Release Notes may be found here: https://docs.openstack.org/releasenotes/murano
